from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, String, Int, Float

Hclust2_Py_V0_1_0 = CommandToolBuilder(tool="hclust2.py", base_command=["hclust2.py"], inputs=[ToolInput(tag="in_the_input_matrix", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="[INPUT_FILE], --inp [INPUT_FILE], --in [INPUT_FILE]\nThe input matrix")), ToolInput(tag="in_output_image_file", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc="[OUTPUT_FILE], --out [OUTPUT_FILE]\nThe output image file [image on screen of not\nspecified]")), ToolInput(tag="in_legend_file", input_type=File(optional=True), prefix="--legend_file", doc=InputDocumentation(doc="[LEGEND_FILE]\nThe output file for the legend of the provided\nmetadata")), ToolInput(tag="in_input_type", input_type=String(optional=True), prefix="--input_type", doc=InputDocumentation(doc="The input type can be a data matrix or distance matrix\n[default data_matrix]")), ToolInput(tag="in_out_table", input_type=File(optional=True), prefix="--out_table", doc=InputDocumentation(doc="Write processed data matrix to file")), ToolInput(tag="in_fname_row", input_type=Int(optional=True), prefix="--fname_row", doc=InputDocumentation(doc="row number containing the names of the features\n[default 0, specify -1 if no names are present in the\nmatrix")), ToolInput(tag="in_sname_row", input_type=Int(optional=True), prefix="--sname_row", doc=InputDocumentation(doc="column number containing the names of the samples\n[default 0, specify -1 if no names are present in the\nmatrix")), ToolInput(tag="in_metadata_rows", input_type=String(optional=True), prefix="--metadata_rows", doc=InputDocumentation(doc="Row numbers to use as metadata[default None, meaning\nno metadata")), ToolInput(tag="in_skip_rows", input_type=File(optional=True), prefix="--skip_rows", doc=InputDocumentation(doc="Row numbers to skip (0-indexed, comma separated) from\nthe input file[default None, meaning no rows skipped")), ToolInput(tag="in_s_perc", input_type=String(optional=True), prefix="--sperc", doc=InputDocumentation(doc="Percentile of sample value distribution for sample")), ToolInput(tag="in_f_top", input_type=Int(optional=True), prefix="--ftop", doc=InputDocumentation(doc="Number of top features to select (ordering based on\npercentile specified by --fperc)")), ToolInput(tag="in_def_na", input_type=String(optional=True), prefix="--def_na", doc=InputDocumentation(doc="Set the default value for missing values [default None\nwhich means no replacement]")), ToolInput(tag="in_f_dist_f", input_type=String(optional=True), prefix="--f_dist_f", doc=InputDocumentation(doc="Distance function for features [default correlation]")), ToolInput(tag="in_s_dist_f", input_type=String(optional=True), prefix="--s_dist_f", doc=InputDocumentation(doc="Distance function for sample [default euclidean]")), ToolInput(tag="in_load_dist_matrix_f", input_type=String(optional=True), prefix="--load_dist_matrix_f", doc=InputDocumentation(doc="Load the distance matrix to be used for features\n[default None].")), ToolInput(tag="in_load_dist_matrix_s", input_type=String(optional=True), prefix="--load_dist_matrix_s", doc=InputDocumentation(doc="Load the distance matrix to be used for samples\n[default None].")), ToolInput(tag="in_load_pickled_dist_matrix_f", input_type=File(optional=True), prefix="--load_pickled_dist_matrix_f", doc=InputDocumentation(doc="Load the distance matrix to be used for features as\npreviously saved as pickle file using hclust2 itself\n[default None].")), ToolInput(tag="in_load_pickled_dist_matrix_s", input_type=File(optional=True), prefix="--load_pickled_dist_matrix_s", doc=InputDocumentation(doc="Load the distance matrix to be used for samples as\npreviously saved as pickle file using hclust2 itself\n[default None].")), ToolInput(tag="in_save_pickled_dist_matrix_f", input_type=File(optional=True), prefix="--save_pickled_dist_matrix_f", doc=InputDocumentation(doc="Save the distance matrix for features to file [default\nNone].")), ToolInput(tag="in_save_pickled_dist_matrix_s", input_type=File(optional=True), prefix="--save_pickled_dist_matrix_s", doc=InputDocumentation(doc="Save the distance matrix for samples to file [default\nNone].")), ToolInput(tag="in_no_f_clustering", input_type=Boolean(optional=True), prefix="--no_fclustering", doc=InputDocumentation(doc="avoid clustering features")), ToolInput(tag="in_no_plot_f_clustering", input_type=Boolean(optional=True), prefix="--no_plot_fclustering", doc=InputDocumentation(doc="avoid plotting the feature dendrogram")), ToolInput(tag="in_no_s_clustering", input_type=Boolean(optional=True), prefix="--no_sclustering", doc=InputDocumentation(doc="avoid clustering samples")), ToolInput(tag="in_no_plot_s_clustering", input_type=Boolean(optional=True), prefix="--no_plot_sclustering", doc=InputDocumentation(doc="avoid plotting the sample dendrogram")), ToolInput(tag="in_f_linkage", input_type=String(optional=True), prefix="--flinkage", doc=InputDocumentation(doc="Linkage method for feature clustering [default\naverage]")), ToolInput(tag="in_s_linkage", input_type=String(optional=True), prefix="--slinkage", doc=InputDocumentation(doc="Linkage method for sample clustering [default average]")), ToolInput(tag="in_dpi", input_type=Int(optional=True), prefix="--dpi", doc=InputDocumentation(doc="Image resolution in dpi [default 150]")), ToolInput(tag="in_log_scale", input_type=Boolean(optional=True), prefix="--log_scale", doc=InputDocumentation(doc="Log scale")), ToolInput(tag="in_title", input_type=String(optional=True), prefix="--title", doc=InputDocumentation(doc="Title of the plot")), ToolInput(tag="in_title_font_size", input_type=Int(optional=True), prefix="--title_fontsize", doc=InputDocumentation(doc="Font size of the title")), ToolInput(tag="in_sqrt_scale", input_type=Boolean(optional=True), prefix="--sqrt_scale", doc=InputDocumentation(doc="Square root scale")), ToolInput(tag="in_no_s_labels", input_type=Boolean(optional=True), prefix="--no_slabels", doc=InputDocumentation(doc="Do not show sample labels")), ToolInput(tag="in_min_v", input_type=Int(optional=True), prefix="--minv", doc=InputDocumentation(doc="Minimum value to display in the color map [default\nNone meaning automatic]")), ToolInput(tag="in_max_v", input_type=Int(optional=True), prefix="--maxv", doc=InputDocumentation(doc="Maximum value to display in the color map [default\nNone meaning automatic]")), ToolInput(tag="in_no_f_labels", input_type=Boolean(optional=True), prefix="--no_flabels", doc=InputDocumentation(doc="Do not show feature labels")), ToolInput(tag="in_max_s_label_len", input_type=Int(optional=True), prefix="--max_slabel_len", doc=InputDocumentation(doc="Max number of chars to report for sample labels\n[default 15]")), ToolInput(tag="in_max_f_label_len", input_type=Int(optional=True), prefix="--max_flabel_len", doc=InputDocumentation(doc="Max number of chars to report for feature labels\n[default 15]")), ToolInput(tag="in_f_label_size", input_type=Int(optional=True), prefix="--flabel_size", doc=InputDocumentation(doc="Feature label font size [default 10]")), ToolInput(tag="in_s_label_size", input_type=Int(optional=True), prefix="--slabel_size", doc=InputDocumentation(doc="Sample label font size [default 10]")), ToolInput(tag="in_fd_end_width", input_type=Int(optional=True), prefix="--fdend_width", doc=InputDocumentation(doc="Width of the feature dendrogram [default 1 meaning\n100% of default heatmap width]")), ToolInput(tag="in_sd_end_height", input_type=Int(optional=True), prefix="--sdend_height", doc=InputDocumentation(doc="Height of the sample dendrogram [default 1 meaning\n100% of default heatmap height]")), ToolInput(tag="in_metadata_height", input_type=Float(optional=True), prefix="--metadata_height", doc=InputDocumentation(doc="Height of the metadata panel [default 0.05 meaning 5%\nof default heatmap height]")), ToolInput(tag="in_metadata_separation", input_type=Float(optional=True), prefix="--metadata_separation", doc=InputDocumentation(doc="Distance between the metadata and data panels.\n[default 0.001 meaning 0.1% of default heatmap height]")), ToolInput(tag="in_colorbar_font_size", input_type=Int(optional=True), prefix="--colorbar_font_size", doc=InputDocumentation(doc="Color bar label font size [default 12]")), ToolInput(tag="in_image_size", input_type=Int(optional=True), prefix="--image_size", doc=InputDocumentation(doc="Size of the largest between width and eight size for\nthe image in inches [default 8]")), ToolInput(tag="in_cell_aspect_ratio", input_type=Float(optional=True), prefix="--cell_aspect_ratio", doc=InputDocumentation(doc="Aspect ratio between width and height for the cells of\nthe heatmap [default 1.0]")), ToolInput(tag="in_colormap", input_type=String(optional=True), prefix="--colormap", doc=InputDocumentation(doc="Color to use for cells below the minimum value of the\nscale [default None meaning bottom color of the scale]")), ToolInput(tag="in_top_c", input_type=String(optional=True), prefix="--top_c", doc=InputDocumentation(doc="Color to use for cells below the maximum value of the\nscale [default None meaning bottom color of the scale]")), ToolInput(tag="in_nan_c", input_type=String(optional=True), prefix="--nan_c", doc=InputDocumentation(doc="Color to use for nan cells [default None]")), ToolInput(tag="in_input_file", input_type=String(optional=True), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_output_file", input_type=String(optional=True), position=1, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_output_image_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_image_file", type_hint=File()), doc=OutputDocumentation(doc="[OUTPUT_FILE], --out [OUTPUT_FILE]\nThe output image file [image on screen of not\nspecified]")), ToolOutput(tag="out_legend_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_legend_file", type_hint=File()), doc=OutputDocumentation(doc="[LEGEND_FILE]\nThe output file for the legend of the provided\nmetadata"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Hclust2_Py_V0_1_0().translate("wdl", allow_empty_container=True)

